# Piot

Load and run device drivers at specific intervals, mainly for sensor reading, based on a single configuration file. Supports activation pins for device multiplexing.

List of drivers currently implemented:

- adsl34x
- amg88xx
- bme280
- bme680
- dht (both 11 and 22)
- dummy (for extra activation pins, for example)
- gdk101
- hcsr04
- hmc5883l
- itg320x
- mhz14
- mlx90614
- pozyx
- qmc5883l
- rd200m
- sds011
- ssd1306
- tfmini
- tsl2561
- tsl2591
